@@ -1,7 +1,10 @@
 # system configuration generated and used by the sysconfig module
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
+ 'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
+ 'ALIGNOF_LONG': 8,
+ 'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'aarch64-linux-gnu-gcc-ar',
@@ -10,20 +13,22 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.8',
- 'BLDLIBRARY': '-lpython3.8',
- 'BLDSHARED': 'aarch64-linux-gnu-gcc -pthread -shared -Wl,-O1 '
-              '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions '
-              ' -Wl,-z,relro -g '
-              '-fwrapv -O2   ',
+ 'BINLIBDEST': '/usr/lib/aarch64-linux-gnu/python3.10',
+ 'BLDLIBRARY': '-lpython3.10',
+ 'BLDSHARED': 'aarch64-linux-gnu-gcc -shared -Wl,-O1 -Wl,-Bsymbolic-functions '
+              '-Wl,-Bsymbolic-functions   '
+              '  '
+              ' -g -fwrapv -O2   '
+              '',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'aarch64-unknown-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': 'aarch64-linux-gnu-gcc -pthread',
+ 'CC': 'aarch64-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall -g '
            ' '
+           '    '
            ' -fstack-protector-strong '
            '-Wformat -Werror=format-security  -g -fwrapv -O2  '
            ' ',
@@ -33,46 +38,57 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-g '
+                     ' '
+                     '   '
                      ' '
                      ' '
                      '-fstack-protector-strong -Wformat -Werror=format-security',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Werror=implicit-function-declaration',
+                            '-Wstrict-prototypes '
+                            '-Werror=implicit-function-declaration '
+                            '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-Wdate-time -D_FORTIFY_SOURCE=2',
- 'CONFIGURE_LDFLAGS': '-Wl,-Bsymbolic-functions '
-                      ' -Wl,-z,relro '
-                      '-g -fwrapv -O2   '
+ 'CONFIGURE_LDFLAGS': '-Wl,-Bsymbolic-functions   '
+                      '  '
+                      ' -g -fwrapv -O2   '
                       '',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--enable-shared' '--prefix=/usr' '--enable-ipv6' "
+ 'CONFIG_ARGS': "'--enable-shared' '--prefix=/usr' "
+                "'--libdir=/usr/lib/aarch64-linux-gnu' '--enable-ipv6' "
                 "'--enable-loadable-sqlite-extensions' "
                 "'--with-dbmliborder=bdb:gdbm' '--with-computed-gotos' "
                 "'--without-ensurepip' '--with-system-expat' '--with-dtrace' "
-                "'--with-system-libmpdec' '--with-system-ffi' "
+                "'--with-system-libmpdec' "
+                "'--with-wheel-pkg-dir=/usr/share/python-wheels/' "
+                "'MKDIR_P=/bin/mkdir -p' '--with-system-ffi' "
                 "'CC=aarch64-linux-gnu-gcc' 'CFLAGS=-g "
                 ' '
+                '    '
                 ' -fstack-protector-strong '
                 "-Wformat -Werror=format-security ' "
-                "'LDFLAGS=-Wl,-Bsymbolic-functions "
-                ' -Wl,-z,relro -g '
+                "'LDFLAGS=-Wl,-Bsymbolic-functions  "
+                '  '
+                '  -g '
                 "-fwrapv -O2   ' "
                 "'CPPFLAGS=-Wdate-time -D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.8',
+ 'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python3.8-0H6wPJ/python3.8-3.8.10/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.8-0H6wPJ/python3.8-3.8.10/build-shared/lcov-report',
+ 'COVERAGE_INFO': '/build/python3.10-PKPqSl/python3.10-3.10.12/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/python3.10-PKPqSl/python3.10-3.10.12/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
              '-D_FORTIFY_SOURCE=2',
- 'CXX': 'aarch64-linux-gnu-g++ -pthread',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.8 /usr/lib/python3.8/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.8',
+ 'CXX': 'aarch64-linux-gnu-g++',
+ 'DESTDIRS': '/usr /usr/lib/aarch64-linux-gnu '
+             '/usr/lib/aarch64-linux-gnu/python3.10 '
+             '/usr/lib/python3.10/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.10',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.8/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.10/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -94,13 +110,15 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
+ 'EXPORTSFROM': '',
+ 'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-38-aarch64-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-310-aarch64-linux-gnu.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
- 'GETTIMEOFDAY_NO_TZ': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
@@ -134,6 +152,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
  'HAVE_CLOCK_SETTIME': 1,
+ 'HAVE_CLOSE_RANGE': 1,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -186,6 +205,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
+ 'HAVE_EVENTFD': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPLICIT_BZERO': 1,
  'HAVE_EXPLICIT_MEMSET': 0,
@@ -256,7 +276,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETSID': 1,
  'HAVE_GETSPENT': 1,
  'HAVE_GETSPNAM': 1,
- 'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
@@ -288,18 +307,23 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
+ 'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
+ 'HAVE_LINUX_CAN_J1939_H': 1,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
+ 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
  'HAVE_LINUX_QRTR_H': 1,
  'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LINUX_VM_SOCKETS_H': 1,
+ 'HAVE_LINUX_WAIT_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -310,7 +334,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
  'HAVE_MEMFD_CREATE': 1,
- 'HAVE_MEMORY_H': 1,
+ 'HAVE_MEMORY_H': 0,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
@@ -325,6 +349,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETPACKET_PACKET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -351,7 +376,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
- 'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 1,
@@ -376,6 +400,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
+ 'HAVE_SEM_CLOCKWAIT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -418,6 +443,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SOCKADDR_STORAGE': 1,
  'HAVE_SOCKETPAIR': 1,
  'HAVE_SPAWN_H': 1,
+ 'HAVE_SPLICE': 1,
  'HAVE_SSIZE_T': 1,
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 1,
@@ -426,7 +452,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
- 'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
@@ -448,11 +473,13 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
+ 'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
  'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 1,
+ 'HAVE_SYS_EVENTFD_H': 1,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
  'HAVE_SYS_IOCTL_H': 1,
@@ -503,7 +530,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
- 'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 1,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -514,6 +540,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UUID_GENERATE_TIME_SAFE': 1,
  'HAVE_UUID_H': 0,
  'HAVE_UUID_UUID_H': 1,
+ 'HAVE_VFORK': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -525,51 +552,51 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
- 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'aarch64-unknown-linux-gnu',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.8 '
-                   '/usr/include/python3.8',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.10 '
+                   '/usr/include/python3.10',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.8',
+ 'INCLUDEPY': '/usr/include/python3.10',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.8.so.1.0',
+ 'INSTSONAME': 'libpython3.10.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'aarch64-linux-gnu-g++ -pthread -shared -Wl,-O1 '
+ 'LDCXXSHARED': 'aarch64-linux-gnu-g++ -shared -Wl,-O1 '
                 '-Wl,-Bsymbolic-functions',
- 'LDFLAGS': '-Wl,-Bsymbolic-functions  '
-            '-Wl,-z,relro -g -fwrapv -O2   '
-            '',
+ 'LDFLAGS': '-Wl,-Bsymbolic-functions    '
+            '  -g -fwrapv '
+            '-O2   ',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.8.so',
+ 'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'aarch64-linux-gnu-gcc -pthread -shared -Wl,-O1 '
-             '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions '
-             ' -Wl,-z,relro -g -fwrapv '
+ 'LDSHARED': 'aarch64-linux-gnu-gcc -shared -Wl,-O1 -Wl,-Bsymbolic-functions '
+             '-Wl,-Bsymbolic-functions    '
+             '  -g -fwrapv '
              '-O2   ',
- 'LDVERSION': '3.8',
+ 'LDVERSION': '3.10',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.8',
- 'LIBDIR': '/usr/lib',
+ 'LIBDEST': '/usr/lib/python3.10',
+ 'LIBDIR': '/usr/lib/aarch64-linux-gnu',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/aarch64-linux-gnu/pkgconfig',
- 'LIBPL': '/usr/lib/python3.8/config-3.8-aarch64-linux-gnu',
+ 'LIBPL': '/usr/lib/python3.10/config-3.10-aarch64-linux-gnu',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.8.a',
+ 'LIBRARY': 'libpython3.10.a',
+ 'LIBRARY_DEPS': 'libpython3.10.a libpython3.10.so libpython3.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
- 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
- 'LINKCC': 'aarch64-linux-gnu-gcc -pthread',
+ 'LIBS': '-lcrypt -ldl  -lm',
+ 'LIBSUBDIRS': 'asyncio \\',
+ 'LINKCC': 'aarch64-linux-gnu-gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic -Wl,-O1 -Wl,-Bsymbolic-functions',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
@@ -581,9 +608,9 @@ build_time_vars = {'ABIFLAGS': '',
                  '-lz                       -lexpat',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.8',
+ 'MACHDESTLIB': '/usr/lib/aarch64-linux-gnu/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'aarch64-linux-gnu-gcc -pthread',
+ 'MAINCC': 'aarch64-linux-gnu-gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': '../Modules/makesetup',
@@ -626,8 +653,8 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
             'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
             'Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
-            'Modules/symtablemodule.o  Modules/pyexpat.o  Modules/xxsubtype.o)',
+            'Modules/_tracemalloc.o  Modules/symtablemodule.o  '
+            'Modules/pyexpat.o  Modules/xxsubtype.o)',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'aarch64-linux-gnu',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"aarch64-linux-gnu\\"',
@@ -637,6 +664,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
+ 'OPENSSL_RPATH': '',
  'OPT': '-DNDEBUG -g -fwrapv -O2 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -646,12 +674,15 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
+ 'PEGEN_HEADERS': '\\',
+ 'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '',
+ 'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo',
+ 'PROFILE_TASK': '-m test --pgo --timeout=1200',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -664,70 +695,83 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3.8',
+ 'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O2 -Wall -g '
                              ' '
+                             '   '
+                             ' '
                              ' '
                              '-fstack-protector-strong -Wformat '
                              '-Werror=format-security  -g -fwrapv -O2  '
                              '  -std=c99 '
                              '-Wextra -Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Werror=implicit-function-declaration  '
-                             '-I../Include/internal -IObjects -IInclude '
-                             '-IPython -I. -I../Include -Wdate-time '
-                             '-D_FORTIFY_SOURCE=2 -fPIC '
+                             '-Wstrict-prototypes '
+                             '-Werror=implicit-function-declaration '
+                             '-fvisibility=hidden  -I../Include/internal '
+                             '-IObjects -IInclude -IPython -I. -I../Include '
+                             '-Wdate-time -D_FORTIFY_SOURCE=2 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall '
               '-g '
               ' '
+              '    '
               ' -fstack-protector-strong '
               '-Wformat -Werror=format-security  -g -fwrapv -O2  '
               ' ',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Werror=implicit-function-declaration  '
-                     '-I../Include/internal',
+                     '-Wstrict-prototypes '
+                     '-Werror=implicit-function-declaration '
+                     '-fvisibility=hidden  -I../Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 '
                    '-Wall -g '
                    ' '
+                   '    '
                    ' '
                    '-fstack-protector-strong -Wformat -Werror=format-security  -g '
                    '-fwrapv -O2    '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration  '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I../Include/internal -IObjects -IInclude -IPython -I. '
                    '-I../Include -Wdate-time -D_FORTIFY_SOURCE=2 -fPIC '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-Bsymbolic-functions '
-                    ' -Wl,-z,relro -g '
-                    '-fwrapv -O2   ',
+ 'PY_CORE_LDFLAGS': '-Wl,-Bsymbolic-functions   '
+                    '  '
+                    ' -g -fwrapv -O2   '
+                    '',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
                 '-D_FORTIFY_SOURCE=2',
+ 'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-Wl,-Bsymbolic-functions '
-               ' -Wl,-z,relro -g '
-               '-fwrapv -O2   ',
+ 'PY_LDFLAGS': '-Wl,-Bsymbolic-functions   '
+               '  '
+               ' -g -fwrapv -O2   '
+               '',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O2 -Wall -g '
                         ' '
+                        '   '
+                        ' '
                         ' '
                         '-fstack-protector-strong -Wformat -Werror=format-security  '
                         '-g -fwrapv -O2   '
                         ' -std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Werror=implicit-function-declaration  '
-                        '-I../Include/internal -IObjects -IInclude -IPython '
-                        '-I. -I../Include -Wdate-time -D_FORTIFY_SOURCE=2 '
-                        '-fPIC',
+                        '-Wstrict-prototypes '
+                        '-Werror=implicit-function-declaration '
+                        '-fvisibility=hidden  -I../Include/internal -IObjects '
+                        '-IInclude -IPython -I. -I../Include -Wdate-time '
+                        '-D_FORTIFY_SOURCE=2 -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -736,14 +780,13 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.8-0H6wPJ/python3.8-3.8.10/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.10-PKPqSl/python3.10-3.10.12/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
+ 'SHLIBS': '-lcrypt -ldl  -lm',
  'SHLIB_SUFFIX': '.so',
- 'SHM_NEEDS_LIBRT': 1,
+ 'SHM_NEEDS_LIBRT': 0,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -764,9 +807,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-38-aarch64-linux-gnu',
+ 'SOABI': 'cpython-310-aarch64-linux-gnu',
  'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': '../Tools/gdb/libpython.py',
+ 'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -774,38 +818,44 @@ build_time_vars = {'ABIFLAGS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
- 'TCLTK_INCLUDES': '',
- 'TCLTK_LIBS': '',
+ 'TCLTK_INCLUDES': '-I/usr/include/tcl8.6',
+ 'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.8-0H6wPJ/python3.8-3.8.10/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.10-PKPqSl/python3.10-3.10.12/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.8-0H6wPJ/python3.8-3.8.10/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.10-PKPqSl/python3.10-3.10.12/build-shared '
                './python ../Tools/scripts/run_tests.py',
+ 'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
+ 'TEST_MODULES': 'yes',
+ 'THREAD_STACK_SIZE': 0,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
+ 'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.8 ../Tools/scripts/update_file.py',
+ 'UPDATE_FILE': '../Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.8',
+ 'VERSION': '3.10',
  'VPATH': '..',
+ 'WHEEL_PKG_DIR': '/usr/share/python-wheels/',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 1,
  'WITH_DYLD': 0,
+ 'WITH_EDITLINE': 0,
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.8-0H6wPJ/python3.8-3.8.10/build-shared',
- 'abs_srcdir': '/build/python3.8-0H6wPJ/python3.8-3.8.10/build-shared/..',
+ 'abs_builddir': '/build/python3.10-PKPqSl/python3.10-3.10.12/build-shared',
+ 'abs_srcdir': '/build/python3.10-PKPqSl/python3.10-3.10.12/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
